Useful Matlab & Python tools for plotting and manipulating outputs from [HippUnfold](https://github.com/khanlab/hippunfold).

Example (Matlab):
```
plot_subject_foldunfold(<HippUnfold_dir>, <subjectID>, 'subfields');
```
![generated plot!](docs/images/subfields_foldunfold.png)

## Installation

Matlab:

```
git clone https://github.com/jordandekraker/hippunfold_toolbox.git
addpath(genpath('hippunfold_toolbox_Matlab'))
```


Python:

```
git clone https://github.com/jordandekraker/hippunfold_toolbox.git
cd hippunfold_toolbox
python setup.py install
```



